pub struct PhaseOptPolynom<C: Coef> { /* private fields */ }Expand description
Represent a polynomial which internally uses the phase change optimization from the
FMCAD’24 paper: “Symbolic Computer Algebra for Multipliers Revisited - It’s All About Orders and Phases”
Note that replace_var is not directly supported. Instead, you will need to use the
replace_... methods specialized for particular gate types.
Implementations
Sourceimpl<C: Coef> PhaseOptPolynom<C>
impl<C: Coef> PhaseOptPolynom<C>
pub fn new(m: Mod) -> Self
pub fn with_max_mod() -> Self
pub fn from_monoms(m: Mod, monoms: impl Iterator<Item = (C, Term)>) -> Self
Sourceimpl<C: Coef> PhaseOptPolynom<C>
Operations that transparently call the corresponding method in the underlying polynom.
impl<C: Coef> PhaseOptPolynom<C>
Operations that transparently call the corresponding method in the underlying polynom.
Sourceimpl<C: Coef> PhaseOptPolynom<C>
Phase information and manipulation
impl<C: Coef> PhaseOptPolynom<C>
Phase information and manipulation
Sourceimpl<C: Coef> PhaseOptPolynom<C>
Routines to replace specific gate types
impl<C: Coef> PhaseOptPolynom<C>
Routines to replace specific gate types
Sourcepub fn replace_and_not(&mut self, out: VarIndex, a: VarIndex, b: VarIndex)
pub fn replace_and_not(&mut self, out: VarIndex, a: VarIndex, b: VarIndex)
out = a && !b
Sourcepub fn replace_and_not_not(&mut self, out: VarIndex, a: VarIndex, b: VarIndex)
pub fn replace_and_not_not(&mut self, out: VarIndex, a: VarIndex, b: VarIndex)
out = !a && !b
pub fn replace_and(&mut self, out: VarIndex, a: VarIndex, b: VarIndex)
pub fn replace_or(&mut self, out: VarIndex, a: VarIndex, b: VarIndex)
pub fn replace_xor(&mut self, out: VarIndex, a: VarIndex, b: VarIndex)
pub fn replace_not(&mut self, out: VarIndex, a: VarIndex)
pub fn replace_identity(&mut self, out: VarIndex, a: VarIndex)
pub fn replace_true(&mut self, out: VarIndex)
pub fn replace_false(&mut self, out: VarIndex)