Crate polysub

Crate polysub 

Structs

ArrayCoef
Custom implementation of a fixed size coefficient using a static sized array.
Mod
The mod factor that we are using.
PhaseOptPolynom
Represent a polynomial which internally uses the phase change optimization from the FMCAD’24 paper: “Symbolic Computer Algebra for Multipliers Revisited - It’s All About Orders and Phases” Note that replace_var is not directly supported. Instead, you will need to use the replace_... methods specialized for particular gate types.
Polynom
Represents a polynomial. Contains additional data structures to allow for fast variable substitution.
Term
VarIndex

Enums

IntCoef
Used to efficiently represent coefficients generated by the polynomial parser. Needs to be converted into a type that implements Coef to actually perform polynomial substitution.

Traits

Coef
A coefficient representation that can be used to perform variable substitution.

Functions

exec_benchmark
Execute a benchmark in the format used by the FastPoly paper (FMCAD’25)
parse_poly